plot_governorates: Plot a map of Tunisia showing the boundaries of Governorates.

View source: R/plot_maps.R

plot_governoratesR Documentation

Plot a map of Tunisia showing the boundaries of Governorates.

Description

Plot a map of Tunisia showing the boundaries of Governorates.

Usage

plot_governorates()

Value

ggplot2 plot


iyedg/tunmaps documentation built on March 18, 2022, 12:08 a.m.