plot_municipalities: Plot a map of Tunisia showing the boundaries of...

View source: R/plot_maps.R

plot_municipalitiesR Documentation

Plot a map of Tunisia showing the boundaries of Municipalities.

Description

Plot a map of Tunisia showing the boundaries of Municipalities.

Usage

plot_municipalities()

Value

ggplot2 plot


iyedg/tunmaps documentation built on March 18, 2022, 12:08 a.m.